@@ -46,7 +46,10 @@ async def create_quote(quote_str: str, author: Author) -> Quote:
         await make_api_request(
             "quotes",
             method="POST",
-            body=f"author={author.id}&quote={quote_str}",
+            body={
+                "author": str(author.id),
+                "quote": quote_str,
+            },
         )
     )
 
@@ -61,7 +64,7 @@ async def create_author(author_str: str) -> Author:
 
     return parse_author(
         await make_api_request(
-            "authors", method="POST", body=f"author={author_str}"
+            "authors", method="POST", body={"author": author_str}
         )
     )
 
